Python: module aes

aes | index /tmp/makerelease-pwman-python.NVQhFLFA/pwman-python-2.8/libpwman/aes.py

# AES wrapper
# Copyright (c) 2023 Michael Büsch <m@bues.ch>
# Licensed under the GNU/GPL version 2 or later.

Modules
os |  |  |

Classes
|  | builtins.object AES
class AES(builtins.object)
| Abstraction layer for the AES implementation.
| Methods defined here: __init__(self) Initialize self. See help(type(self)) for accurate signature. decrypt(self, key, iv, data, legacyPadding=False) Decrypt data. encrypt(self, key, iv, data) Encrypt data. Class methods defined here: get() from builtins.type Get the AES singleton. Data descriptors defined here: __dict__ dictionary for instance variables (if defined) __weakref__ list of weak references to the object (if defined) Data and other attributes defined here: BLOCK_SIZE = 16

Data
|  | __all__ = ['AES']